//
//  LeaderBoardViewController.swift
//  GestureDemo
//
//  Created by Sally McNichols on 2/16/15.
//  Copyright (c) 2015 Sally McNichols. All rights reserved.
//

import UIKit

class LeaderBoardViewController: UIViewController, UITableViewDelegate,
    UITableViewDataSource {

    @IBOutlet var tableView: UITableView!
    // players on the leaderboard
    var leaders: [Player] = []
    
    func fetchData() {
        // get all the players on the leaderboard from parse
        var query = PFQuery(className: "Player")
        query.findObjectsInBackgroundWithBlock {
            (objects: [AnyObject]!, error: NSError!) -> Void in
            if error == nil {
                for object in objects {
                    var name: String = object.objectForKey("name") as! String
                    var score: String = object.objectForKey("score") as! String
                    var player: Player = Player(name: name)
                    player.score = Int(score)!
                    self.leaders.append(player)
                }
                // sort the players according to score
                self.sortLeaders()
                // display on tableview
                self.tableView.reloadData()
            }
        }
        
    }
    
    override func viewDidLoad() {
        super.viewDidLoad()
        self.tableView.delegate = self
        self.tableView.dataSource = self
    }
    
    // The view doesn't load ever time when you view it in a TabViewController,
    // so any time you want something to happen when you view LeaderBoardViewController
    // do it in the viewWillAppear function which is called every time you view this VC
    override func viewWillAppear(animated: Bool) {
        self.leaders = []
        fetchData()
    }
    
    // sort leaders by score using sort function and closure
    // (which is like an anon function in a way: it tells sort how to
    // sort the elements in the array)
    func sortLeaders() {
        self.leaders.sortInPlace({$0.score > $1.score})
    }
    
    // in each cell have player name and score
    func tableView(tableView: UITableView, cellForRowAtIndexPath indexPath: NSIndexPath) -> UITableViewCell {
        let cell = tableView.dequeueReusableCellWithIdentifier("player") as? LeaderBoardTableViewCell ?? LeaderBoardTableViewCell()
        
        let player: Player = self.leaders[indexPath.row]
        cell.playerName.text = player.name
        cell.playerScore.text = String(player.score)
        
        return cell
    }
    
    func tableView(tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return self.leaders.count
    }


}
